<?php

session_start();

//ログイン済みかを確認
if (!isset($_SESSION['USER'])) {
    header('Location: ./login.php');
    exit;
}

ini_set('display_errors',"On");

//特殊文字をテキスト化する関数
function h($s){
    return htmlspecialchars($s,ENT_QUOTES,"UTF-8");
}

require_once('./sqlEngine.php');

//sqlEngine.phpのインスタンス
$sqleg=new Sqe();

$result=$sqleg->getAll();

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>データの一覧</title>
    <style type="text/css">
        body{
            font-family: -apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,"Helvetica Neue",
                Arial,"Noto Sans",sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol",
                "Noto Color Emoji";
                font-size: 15px;
                color: #666;
                width: 100%;
        }       

        body main{
            max-width: 1000px;
            margin: 20px auto;
        }

        body main table{
            width: 100%;
            border-collapse: separate;
            border-spacing: 0;
        }

        body main table #th:first-child{
            border-radius: 5px 0 0 0;
        }

        body main table #th:last-child{
            border-radius: 0 5px 0 0;
            border-right: 1px solid darkslateblue;
        }

        body main table th{
            text-align: center;
            color: white;
            background-color:steelblue;
            border-left: 1px solid darkslateblue;
            border-top: 1px solid darkslateblue;
            border-bottom: 1px solid darkslateblue;
            box-shadow: opx 1px 1px rgba(255,255,255,0.3) inset;
            width: 14%;
            padding: 10px 0           
        }

        body main table td{
            text-align: center;
            border-left: 1px solid lightslategray;
            border-bottom: 1px solid lightslategray;
            border-top: none;
            box-shadow: 0px -3px 1px #eee inset;
            width: 14%;
            padding: 10px 0;
        }

        body main table td:last-child{
            border-right: 1px solid lightslategray;
        }

        body main table tr:last-child td:first-child{
            border-radius: 0 0 0 5px;
        }

        body main table tr:last-child td:last-child{
            border-radius: 0 0 5px 0;
        }

        .btn a{
            height: 44px;
            border-radius: 22px;
            padding: 10px 20px;
            background-color: #6c757d;
            color: #fff;
            line-height: 44px;
            text-decoration: none;
        }


    </style>
</head>
<body>
    <p class="btn"><a href="./topPage.php"> 戻る</a></p>

    <main>
        <table>
            <tr>
                <th id="th">発見者</th>
                <th id="th">発見日</th>
                <th id="th">分類(施設)</th>
                <th id="th">異常内容</th>
                <th id="th">緊急度</th>
                <th id="th">状態</th>
                <th id="th">リンク</th>
            </tr>

            <?php foreach ($result as $column): ?>

                <?php
                    $facility='';
                    if((int)$column['facility']===1){$facility='路面';}
                    if((int)$column['facility']===2){$facility='路面(側)';}
                    if((int)$column['facility']===3){$facility='法面';}
                    if((int)$column['facility']===4){$facility='擁壁';}
                    if((int)$column['facility']===5){$facility='排水施設';}
                    if((int)$column['facility']===6){$facility='橋梁';}
                    if((int)$column['facility']===7){$facility='歩道';}
                    if((int)$column['facility']===8){$facility='道路標識';}
                    if((int)$column['facility']===9){$facility='植栽帯';}
                    if((int)$column['facility']===10){$facility='冬季交通確保';}
                    if((int)$column['facility']===11){$facility='道路状況';}
                    if((int)$column['facility']===12){$facility='その他';}

                    $substance='';
                    if((int)$column['substance']===1){$substance='路面補修';}
                    if((int)$column['substance']===2){$substance='路面清掃';}
                    if((int)$column['substance']===3){$substance='法面復旧';}
                    if((int)$column['substance']===4){$substance='落下物処理';}
                    if((int)$column['substance']===5){$substance='死骸撤去';}
                    if((int)$column['substance']===6){$substance='除草';}
                    if((int)$column['substance']===7){$substance='支障木撤去';}
                    if((int)$column['substance']===8){$substance='側溝清掃';}
                    if((int)$column['substance']===9){$substance='視線誘導標修繕';}
                    if((int)$column['substance']===10){$substance='資材支給';}
                    if((int)$column['substance']===11){$substance='その他';}

                    $urgency='';
                    if((int)$column['urgency']===1){$urgency='指定無し';}
                    if((int)$column['urgency']===2){$urgency='至急';}
                    if((int)$column['urgency']===3){$urgency='3日以内';}
                    if((int)$column['urgency']===4){$urgency='1週間以内';}
                    if((int)$column['urgency']===5){$urgency='2週間以内';}
                    if((int)$column['urgency']===6){$urgency='1ヶ月以内';}
                    if((int)$column['urgency']===7){$urgency='1ヶ月以上';}

                    $astate='';
                    if((int)$column['astate']===1){$astate='未処置';}
                    if((int)$column['astate']===2){$astate='現場確認済';}
                    if((int)$column['astate']===3){$astate='応急処置済';}
                    if((int)$column['astate']===4){$astate='業者依頼済';}
                    if((int)$column['astate']===5){$astate='処置完了';}
                ?>

                <tr>
                    <td><?php echo h($column['registrant']); ?></td>
                    <td><?php echo h($column['reportDay']);?></td>
                    <td><?php echo $facility;?></td>
                    <td><?php echo $substance;?></td>
                    <td><?php echo $urgency;?></td>
                    <td><?php echo $astate;?></td>
                    <td><a href="./upLoad.php?id=<?php echo $column['id']; ?> " target='_blank'>更新</a></td>
                </tr> 

            <?php endforeach; ?>
            
        </table>
        
    </main>
</body>
</html>